// Copyright (c) 2012 Albrecht Weinert, Bochum
// $Id: maketime_utc.h 2 2017-01-25 16:49:03Z albrecht $

/** 
 * \file maketime_utc.h
 * 
 *  UTC time stamp of of \ref intro_sec "weAutSys"' last make
 * 
 *  This file's source (where most of it is copied from) name is
 *  maketime_utc.txt. 
 *  It contains the constant (start) text for the file maketime_utc.h which is
 *  automatically created  by the \c makefile. To create it by command line 
 *  use \code
 *  
 *  @REM in Windows (batch file)
 *    echo f | xcopy /Y .\include\maketime_utc.txt .\include\maketime_utc.h
 *    %AVR32_HOME%\utils\bin\date.exe +%%s >> .\include\maketime_utc.h
 *  
 *  #    in Linux (bash script)
 *    cp -f ./include/maketime_utc.txt ./include/maketime_utc.h #
 *    date +%s >> ./include/maketime_utc.h #
 *  \endcode
 *  
 *  maketime_utc.h's single purpose is to hold the UTC time of make as macro 
 *  \ref MAKETIME_UTC.
 *  
 * This file is part of \ref intro_sec "weAutSys" &nbsp;
 *          <<a href="http://weinert-automation.de">weinert-automation.de</a>>
 *
 * &nbsp; \ref copyLicNote " Copyright &copy; " 2012 Albrecht Weinert, Bochum
 * \author  Albrecht Weinert  &nbsp;
 *                            <<a href="http://a-weinert.de">a-weinert.de</a>>
 * $Revision: 2 $
 * $Date: 2017-01-25 16:49:03 +0000 (Wed, 25 Jan 2017) $
 */
//  SVN last change by $Author: albrecht $

/** The UTC stamp of last make
 * 
 *  The value was set automatically in the building / deployment process as
 *  seconds since 1970-01-01 UTC.
 *  
 *  It is given by \c date.exe +%s (part of WinAVR) respectively on 
 *  Linux as development platform by just \c date +%s 
 *
 *  \showinitializer
 *  \sa DEFAULT_START_TIME
 *  \sa OFFSET2UNIXTIME
 */
#define MAKETIME_UTC 1485361796
